(function ($) {
"use strict";

function gg_isotope_init() {

	if($('.el-grid:not(.gg-slick-carousel)').length > 0){
	    var layout_modes = {
	        fitrows: 'fitRows',
	        masonry: 'masonry'
	    }
	    jQuery('.gg_posts_grid').each(function(){
	        var $container = jQuery(this);
	        var $grid = $container.find('.el-grid:not(.gg-slick-carousel):not([data-layout-mode="list"])');
	        var layout_mode = $grid.attr('data-layout-mode');
            var columns = $grid.attr('data-columns');
	           
            //initiate isotope only if layout has more than 1 column
            if ( columns == '1' ) {
                return;
            }

	        $grid.isotope({
	            // options
                percentPosition: true,
	            itemSelector : '.isotope-item',
	            layoutMode : (layout_modes[layout_mode]==undefined ? 'fitRows' : layout_modes[layout_mode]),
                transitionDuration: '0.8s',
                // only opacity for reveal/hide transition
                hiddenStyle: {
                    opacity: 0
                },  
                visibleStyle: {
                    opacity: 1
                }
	        });

	        jQuery(window).on('load resize', function() {
				$grid.imagesLoaded().progress( function() {
                    $grid.isotope('layout');
                });
	        });

	    });
	}
}

/* SlickCarousel */
function gg_slickcarousel_init() {
	if($('.gg-slick-carousel:not(.gg_filter)').length > 0){
		$( '.gg-slick-carousel:not(.gg_filter)' ).each(function(){

			var $this = $(this);

			//Initialize slick
		  $this.slick();
			
			var filtered = false;

			$('.gg_filter.gg-slick-carousel a').on('click', function(e){
				e.preventDefault();
				$(this).parent().parent().find('.active').removeClass('active');
				$(this).parent().addClass('active');

		        var gg_filter = $(this).parent().parent().parent().parent().find('.el-grid.gg-slick-carousel');

		        if ($(this).attr('data-filter') == '*') {
			      	gg_filter.slick('slickUnfilter');
			      	gg_filter.slick('slickGoTo',0);
				    filtered = false;
			    } else {
				  	gg_filter.slick('slickFilter',$(this).attr('data-filter'));
				  	gg_filter.slick('slickGoTo',0);
				    filtered = true;
			    } 
			});

			//Refresh and animate the carousel from the megamenu
			$( ".navbar-default .navbar-nav > li.is-megamenu > a" ).on( "click", function() {
				var cur_slider = $(this).parent().find('.gg-slick-carousel');
				cur_slider.css({"opacity": 0});
				cur_slider.resize().animate({opacity: 1}, 1000);
			});

		});

	}
}

/* Counter */
function gg_counter_init(){
	if($('.counter').length > 0){
		jQuery('.counter-wrapper').waypoint(function() {
			$('.counter').each(function() {
				if(!$(this).hasClass('initialized')){
					$(this).addClass('initialized');
                    var $this     = $(this),
                    countToNumber = $this.attr('data-number'),
                    refreshInt    = $this.attr('data-interval'),
                    speedInt      = $this.attr('data-speed');

					$(this).countTo({
						from: 0,
						to: countToNumber,
						speed: speedInt,
						refreshInterval: refreshInt
					});
				}
			});
		}, { offset: '85%' });
	}
}

/* Swiper Carousel */
function gg_swipercarousel_init(selector) {

    var id             = $(selector).data('uid'),
    gg_slidesPerView   = $(selector).data('slidesperview'),
    gg_slidesPerColumn = $(selector).data('slidespercolumn'),
    gg_spaceBetween    = $(selector).data('spacebetween'),
    gg_initialSlide    = $(selector).data('initialslide'),
    gg_direction       = $(selector).data('direction'),
    gg_speed           = $(selector).data('speed'),
    gg_loop            = $(selector).data('loop'),
    gg_centeredslides  = $(selector).data('centeredslides'),
    gg_effect          = $(selector).data('effect'),
    gg_autoplay        = $(selector).data('autoplay'),
    gg_paginationtype  = $(selector).data('paginationtype');

    var swiper = new Swiper(selector, {
        direction: gg_direction,
        autoplay: gg_autoplay,
        pagination: {
            el: '.swiper-pagination',
            type: gg_paginationtype,
            clickable: true,
        },
        navigation: {
            nextEl: '.swiper-button-next',
            prevEl: '.swiper-button-prev',
            clickable: true,
        },
        slidesPerView: gg_slidesPerView,
        slidesPerColumn: gg_slidesPerColumn,
        spaceBetween: gg_spaceBetween,
        loop: gg_loop,
        centeredSlides: gg_centeredslides,
        effect: gg_effect,
        fade: {
            crossFade: true
        },
        autoHeight: true

    });
}

$(document).ready(function () {

	gg_slickcarousel_init();
    gg_counter_init();
    gg_isotope_init();

    //Swiper carousel
    if( $('.swiper-container').length > 0 ) {
        $('.swiper-container').each(function() {
            gg_swipercarousel_init(this);
        });
    }

	/* Slider under header */
	function gg_slider_position() {
		var header_nav = $('header nav.navbar');
		if( $('body').hasClass('gg-slider-is-beneath_header') ) {
			var headerHeight = header_nav.height();
			var revSlider = $('header .subheader-slider').first();
			revSlider.css({
				'marginTop' : - headerHeight
			});
		}
	}

	//Load, resize, added to cart
	$(window).bind("load resize",function(e){
	 	gg_slider_position();
	});
    

    //Sticky menu
    function gg_sticky_menu() {
		if($('body.gg-has-stiky-menu').length > 0) {
			var main_menu = $('header.site-header .navbar');
			var main_menu_height = main_menu.outerHeight();

			if($('body.admin-bar').length > 0) {
				var admin_bar = 31;
			} else {
				var admin_bar = 0;
			}


       		$(window).on('scroll', function () {

       			if ($(this).scrollTop() > main_menu_height) {

       				main_menu.addClass('navbar-fixed-top');
       				$('body.gg-has-stiky-menu').css('padding-top', main_menu_height +'px');

       				setTimeout(function() {
					    $('header.site-header .navbar.navbar-fixed-top').css('top', admin_bar +'px');
					}, 500);

       			} else {

       				main_menu.removeClass('navbar-fixed-top');
       				$('body.gg-has-stiky-menu').css('padding-top', '0');
       				main_menu.css('top', '');

       			}

       			//Second animation
       			if ($(this).scrollTop() > main_menu_height + 1800) {
       				main_menu.addClass('gg-shrink');
       			} else {
       				main_menu.removeClass('gg-shrink');
       			}

       			

       		});
		}
	}

    //Load, resize, added to cart
	$(window).bind("load resize",function(e){
	 	gg_sticky_menu();
	});


});

	
})(jQuery);