<?php

class tracian_OKThemes_Theme_Demo_Data_Importer {



    /**

     * Holds a copy of the object for easy reference.

     *

     * @since 2.2.0

     *

     * @var object

     */

    private static $instance;

    

    /**

     * Constructor. Hooks all interactions to initialize the class.

     *

     * @since 2.2.0

     */

    public function __construct() {

        

        self::$instance = $this;



        add_action( 'admin_init', array($this, 'tracian_theme_activation') );

        add_action( 'admin_menu', array($this, 'tracian_add_admin') );

        add_action( 'admin_print_scripts', array($this, 'tracian_enqueue_admin_assets') );

    }



    // Custom assets for admin pages

    function tracian_enqueue_admin_assets() {

        wp_enqueue_style( 'tracian-theme-admin', get_template_directory_uri() . '/admin/importer/assets/admin-style.css' );

    }



    // Redirect to Demo Import page after Theme activation

    public function tracian_theme_activation() {

        global $pagenow;

        if ( is_admin() AND $pagenow == 'themes.php' AND isset( $_GET['activated'] ) ) {

            //Redirect to demo import

            header( 'Location: ' . admin_url( 'admin.php?page=tracian-home' ) );

        }

    }



    /**

     * Add Panel Page

     *

     * @since 2.2.0

     */

    public function tracian_add_admin() {

        //Output buffering

        ob_start();

        add_theme_page("About the theme", "About the theme", 'switch_themes', 'tracian-home', array($this, 'tracian_welcome_page'));

        if ( class_exists( 'acf' ) ) {

            add_theme_page("Customizer Import", "Import theme options", 'switch_themes', 'import', array($this, 'tracian_import_option_page'));

            add_theme_page("Customizer Export", "Export theme options", 'switch_themes', 'export', array($this, 'tracian_export_option_page'));

        }

    }





    public function tracian_welcome_page() {



        $theme = wp_get_theme();

        if ( is_child_theme() ) {

            $theme = wp_get_theme( $theme->get( 'Template' ) );

        }

        $theme_name = $theme->get( 'Name' );

        $theme_version = $theme->get( 'Version' );



        $return_url = admin_url('admin.php?page=tracian-home');



        

        ?>

        

        <div class="gg-admin-welcome-page">

            



            <div class="welcome-panel" style="padding-bottom: 23px;">

                <div class="welcome-panel-content">



                    <h2><?php echo sprintf( __( 'Welcome to <strong>%s</strong>', 'tracian' ), $theme_name . ' ' . $theme_version ) ?></h2>

                    <p class="about-description"><?php _e( 'Beautifully crafted WordPress theme ready to take your wine journey to the next level.', 'tracian' ) ?></p>



                    <div class="welcome-panel-column-container">

                        <div class="welcome-panel-column">

                            <h3><i class="dashicons dashicons-screenoptions"></i><?php _e( 'Install Plugins', 'tracian' ) ?></h3>

                            <p><?php echo sprintf( __( '%s has bundled popular premium plugins which greatly increases the flexibility of the theme. Install them in order to maximize the theme power.', 'tracian' ), $theme_name ); ?></p>

                            <a class="button button-primary" href="<?php echo admin_url( 'admin.php?page=tgmpa-install-plugins' ); ?>"><?php _e( 'Install Plugins', 'tracian' ) ?></a>

                        </div>

                        <div class="welcome-panel-column">

                            <h3><i class="dashicons dashicons-download"></i><?php _ex( 'Import Demo Content', 'noun', 'tracian' ) ?></h3>

                            <p><?php _e( 'If you have installed this theme on a clean WordPress installation then this is where you\'ll want to go next. This feature imports the demo content.', 'tracian' ) ?></p>

                            <a class="button button-primary" href="<?php echo admin_url( 'admin.php?page=tracian-demo-import' ); ?>">

                                <?php _e( 'Import Demo Content', 'tracian' ) ?></a>

                        </div>

                        <div class="welcome-panel-column welcome-panel-last">

                            <h3><i class="dashicons dashicons-admin-appearance"></i><?php _e( 'Customize Appearance', 'tracian' ) ?></h3>

                            <p><?php _e( 'Customize the look and feel of your site with the help of the Theme Options panel.', 'tracian' ) ?></p>

                            <a class="button button-primary" href="<?php echo admin_url( 'admin.php?page=theme-options' ); ?>"><?php _e( 'Go to Theme Options', 'tracian' ) ?></a>

                        </div>

                    </div>

                </div>

            </div>



            <div class="footer" style="display:none;">

                <ul">

                    <li>

                        <i class="dashicons dashicons-editor-help"></i>

                        <a href="#" target="_blank"><?php _e( 'Online Documentation', 'tracian' ) ?></a>

                    </li>

                    <li>

                        <i class="dashicons dashicons-sos"></i>

                        <a href="#" target="_blank"><?php _e( 'Support Portal', 'tracian' ) ?></a>

                    </li>

                    <li>

                        <i class="dashicons dashicons-backup"></i>

                        <a href="#" target="_blank"><?php _e( 'Theme Changelog', 'tracian' ) ?></a>

                    </li>

                </ul>

            </div>



        </div>

        <?php

    }



    public function tracian_import_option_page() {

        global $wp_filesystem;

        WP_Filesystem();

    ?>

      <div class="wrap">

        <div id="icon-tools" class="icon32"><br></div>

        <h2><?php esc_html_e('Customizer Import', 'tracian');?></h2>

        <?php

        if ( isset( $_FILES['import'] ) && check_admin_referer( 'gg-customizer-import' ) ) {

          if ( $_FILES['import']['error'] > 0 ) {

            wp_die( 'An error occured.' );

          } else {

            $file_name = $_FILES['import']['name'];

            $file_name = explode( '.', $file_name );

            $file_ext  = strtolower( end( $file_name ) );

            $file_size = $_FILES['import']['size'];

            if ( ( $file_ext == 'json' ) && ( $file_size < 500000 ) ) {

              

              $encode_options = $wp_filesystem->get_contents( $_FILES['import']['tmp_name'] );



              $options        = json_decode( $encode_options, true );



              foreach ( $options as $key => $value ) {

                update_option( $key, $value );

              }



              echo '<div class="updated"><p>'.esc_html__('All options were restored successfully!', 'tracian').'</p></div>';

            } else {

              echo '<div class="error"><p>'.esc_html__('Invalid file or file size too big.', 'tracian').'</p></div>';

            }

          }

        }

        ?>

        <form method="post" enctype="multipart/form-data">

          <?php wp_nonce_field( 'gg-customizer-import' ); ?>

          <p><?php esc_html_e('If you have settings in a backup file (json) on your computer, the Import system can import it into this site. To get started, upload your backup file using the form below.', 'tracian'); ?></p>

          <p><?php esc_html_e('Choose a file (json) from your computer:', 'tracian');?> <input type="file" id="customizer-upload" name="import"></p>

          <p class="submit">

            <input type="submit" name="submit" id="customizer-submit" class="button" value="Upload file and import">

          </p>

        </form>

      </div>

    <?php

    }



    /**

     * [Export theme options]

     *

     * @since 2.2.0

     *

     */



    public function tracian_export_option_page() {

      if ( ! isset( $_POST['export'] ) ) {

      ?>

        <div class="wrap">

          <div id="icon-tools" class="icon32"><br></div>

          <h2><?php esc_html_e('Customizer Export', 'tracian');?></h2>

          <form method="post">

            <?php wp_nonce_field( 'gg-customizer-export' ); ?>

            <p><?php esc_html_e('When you click the button below, the Export system will create a backup file (json) for you to save to your computer.', 'tracian'); ?></p>

            <p><?php esc_html_e('This text file can be used to restore your settings or to easily setup another website with the same theme settings.', 'tracian'); ?></p>

            <p><em><?php esc_html_e('Please note that this export manager backs up only your theme settings and not your content. To backup your content, please use the WordPress Export Tool.', 'tracian'); ?></em></p>

            <p class="submit"><input type="submit" name="export" class="button button-primary" value="Download Backup File"></p>

          </form>

        </div>



      <?php



        $options   = get_theme_mods();



      } elseif ( check_admin_referer( 'gg-customizer-export' ) ) {



        $blogname  = strtolower( str_replace(' ', '', get_option( 'blogname' ) ) );

        $date      = date( 'm-d-Y' );

        $json_name = $blogname . '-customizer-' . $date;



        // global

        global $wpdb;



        // vars

        $theme_options = array();



        $rows = $wpdb->get_results($wpdb->prepare(

            "SELECT option_name, option_value FROM $wpdb->options WHERE option_name LIKE %s OR option_name LIKE %s",

            'options' . '_%' ,

            '_' . 'options' . '_%' 

        ), ARRAY_A);

        

        if( !empty($rows) ) {

            

            foreach( $rows as $row ) {

                

                $theme_options[ $row['option_name'] ] = maybe_unserialize($row['option_value']);

                

            }

            

        }



        ob_clean();



        echo json_encode( $theme_options );



        header( 'Content-Type: text/json; charset=' . get_option( 'blog_charset' ) );

        header( 'Content-Disposition: attachment; filename=' . $json_name . '.json' );



        exit();



      }

    }     





}



new tracian_OKThemes_Theme_Demo_Data_Importer;