<?php

// exit if accessed directly
if( ! defined( 'ABSPATH' ) ) exit;


// check if class already exists
if( !class_exists('tracian_acf_field_customizer_logo') ) :


class tracian_acf_field_customizer_logo extends acf_field {
	
	
	/*
	*  __construct
	*
	*  This function will setup the field type data
	*
	*  @type	function
	*  @date	5/03/2014
	*  @since	5.0.0
	*
	*  @param	n/a
	*  @return	n/a
	*/
	
	function __construct( $settings ) {
		
		/*
		*  name (string) Single word, no spaces. Underscores allowed
		*/
		
		$this->name = 'customizer_logo';
		
		
		/*
		*  label (string) Multiple words, can include spaces, visible when selecting a field type
		*/
		
		$this->label = esc_html__('Customizer Logo', 'tracian');
		
		
		/*
		*  category (string) basic | content | choice | relational | jquery | layout | CUSTOM GROUP NAME
		*/
		
		$this->category = 'basic';
		
		
		/*
		*  defaults (array) Array of default settings which are merged into the field object. These are used later in settings
		*/
		
		$this->defaults = array(
			'font_size'	=> 14,
		);
		
		
		/*
		*  l10n (array) Array of strings that are used in JavaScript. This allows JS strings to be translated in PHP and loaded via:
		*  var message = acf._e('FIELD_NAME', 'error');
		*/
		
		$this->l10n = array(
			'error'	=> esc_html__('Error! Please enter a higher value', 'tracian'),
		);
		
		
		/*
		*  settings (array) Store plugin settings (url, path, version) as a reference for later use with assets
		*/
		
		$this->settings = $settings;
		
		
		// do not delete!
    	parent::__construct();
    	
	}
	
	
	/*
	*  render_field_settings()
	*
	*  Create extra settings for your field. These are visible when editing a field
	*
	*  @type	action
	*  @since	3.6
	*  @date	23/01/13
	*
	*  @param	$field (array) the $field being edited
	*  @return	n/a
	*/
	
	function render_field_settings( $field ) {
		
		/*
		*  acf_render_field_setting
		*
		*  This function will create a setting for your field. Simply pass the $field parameter and an array of field settings.
		*  The array of settings does not require a `value` or `prefix`; These settings are found from the $field array.
		*
		*  More than one setting can be added by copy/paste the above code.
		*  Please note that you must also have a matching $defaults value for the field name (font_size)
		*/

        acf_render_field_setting( $field, array(
            'label'         => esc_html__('Select type','tracian'),
            'type'          => 'select',
            'name'          => 'select_custom_type_field',
            'choices'       => array(
                            'customizer_logo_link' => esc_html__('Customizer logo link','tracian') ,
                            'customizer_css_link'  => esc_html__('Customizer css editor link','tracian') ,
                            'customizer_shop_link' => esc_html__('Customizer shop link','tracian') ,
                )
        ));
		
	}
	
	
	
	/*
	*  render_field()
	*
	*  Create the HTML interface for your field
	*
	*  @param	$field (array) the $field being rendered
	*
	*  @type	action
	*  @since	3.6
	*  @date	23/01/13
	*
	*  @param	$field (array) the $field being edited
	*  @return	n/a
	*/
	
	function render_field( $field ) {

        if ($field['select_custom_type_field'] == 'customizer_logo_link') {
            $query['autofocus[section]'] = 'title_tagline';
        } elseif ($field['select_custom_type_field'] == 'customizer_css_link') {
            $query['autofocus[section]'] = 'custom_css';
        } elseif ($field['select_custom_type_field'] == 'customizer_shop_link') {
            $query['autofocus[section]'] = 'woocommerce_product_catalog';
        }
        
        $section_link = add_query_arg( $query, admin_url( 'customize.php' ) );
        
		?>
        <a href="<?php echo esc_url( $section_link ); ?>"><?php esc_html_e('Link to Section','tracian'); ?></a>
       	
        <?php
	}
		
}


// initialize
new tracian_acf_field_customizer_logo( $this->settings );


// class_exists check
endif;

?>