<?php
/* Check if extension is activated */
function tracian_is_extension_activated( $extension = '' ) {
    return class_exists( $extension ) ? true : false;
}

// Verify if woocommerce is active
if ( ! function_exists( 'tracian_is_wc_activated' ) ) {
    function tracian_is_wc_activated() {
        if ( class_exists( 'woocommerce' ) ) { 
            return true;
        } else { 
            return false;
        }
    }
}

// Verify if WPML is active
if ( ! function_exists( 'tracian_is_wpml_activated' ) ) {
    function tracian_is_wpml_activated() {
        if ( class_exists( 'SitePressLanguageSwitcher' ) ) { 
            return true; 
        } else { 
            return false;
        }
    }
}

if ( tracian_is_wpml_activated() ) {
    //Disable WPML styles
    define('ICL_DONT_LOAD_NAVIGATION_CSS', true);
    define('ICL_DONT_LOAD_LANGUAGE_SELECTOR_CSS', true);
    define('ICL_DONT_LOAD_LANGUAGES_JS', true);
}

// Set VC as part of the theme
if( function_exists('vc_set_as_theme') ) {

  add_action( 'vc_before_init', 'tracian_vcSetAsTheme' );
  function tracian_vcSetAsTheme() {
      vc_set_as_theme();
  }

    $list = array(
        'page',
        'product',
    );
    vc_set_default_editor_post_types( $list );
}

// Hide activation and update specific parts of Slider Revolution
if( function_exists('set_revslider_as_theme') ) {

    add_action( 'init', 'tracian_rev_slider' );
    function tracian_rev_slider() {
        set_revslider_as_theme();
    }

    //Disable notices
    remove_action('admin_notices', array('RevSliderAdmin', 'add_plugins_page_notices'));
}

// add class if post has thumbnail
function has_thumb_class($classes) {
    global $post;
    if( has_post_thumbnail($post->ID) ) { $classes[] = 'has_thumb'; }
 
        return $classes;
}
add_filter('post_class', 'has_thumb_class');

//Get the global page id
if (! function_exists('tracian_global_page_id')) :
function tracian_global_page_id() {
  
  global $wp_query;

  if ( tracian_is_wc_activated() && is_shop() ) {
    $current_page_id = get_option( 'woocommerce_shop_page_id' );
  // If there is a post
  } elseif ( is_single() || ( is_home() && !is_front_page() ) || ( is_page() && !is_front_page() ) ) {
    $current_page_id = $wp_query->post->ID;

  } else {
    $current_page_id = '';
  }
  
  if(is_home()){
      if('page' == get_option('show_on_front')){
          if(is_front_page()){
              $current_page_id = get_option('page_on_front');
          }else{
              $current_page_id = get_option('page_for_posts');
          }
      }
  }

  return $current_page_id;

}
endif;

if (! function_exists('tracian_header_title')) :
function tracian_header_title() {
    global $page, $paged;

    $search = get_query_var('s');
    $title = '';

    // If there is a post
    if ( is_single() || ( is_home() && !is_front_page() ) || ( is_page() && !is_front_page() ) ) {
        $title = single_post_title( '', false );
    }

    // If there's a post type archive
    if ( is_post_type_archive() ) {
        $post_type = get_query_var( 'post_type' );
        if ( is_array( $post_type ) ) {
            $post_type = reset( $post_type );
        }
        $post_type_object = get_post_type_object( $post_type );
        if ( ! $post_type_object->has_archive ) {
            $title = post_type_archive_title( '', false );
        }
    }

    // If there's a category or tag
    if ( is_category() || is_tag() ) {
        $title = single_term_title( '', false );
    }

    // If there's a taxonomy
    if ( is_tax() ) {
        $term = get_queried_object();
        if ( $term ) {
            $tax   = get_taxonomy( $term->taxonomy );
            $title = single_term_title( false );
        }
    }

    // If there's an author
    if ( is_author() && ! is_post_type_archive() ) {
        $author = get_queried_object();
        if ( $author ) {
            $title = $author->display_name;
        }
    }

    // Post type archives with has_archive should override terms.
    if ( is_post_type_archive() && $post_type_object->has_archive ) {
        $title = post_type_archive_title( '', false );
    }

    if ( is_year() || is_month() || is_day() ) {
        $title = get_the_archive_title();
    }

    // If it's a search
    if ( is_search() ) {
        /* translators: 1 search phrase */
        $title = sprintf(esc_html__('Search Results For: %1$s','tracian'), strip_tags($search));
    }

    if ( tracian_is_wc_activated() && (is_shop()) ) {
        $title = get_the_title(wc_get_page_id( 'shop' ));
    }

    if ( tracian_is_wc_activated() && is_page() && is_wc_endpoint_url() ) {
        $endpoint = WC()->query->get_current_endpoint();
        if ( $endpoint_title = WC()->query->get_endpoint_title( $endpoint ) ) {
            $title = $endpoint_title;
        }
    }

    echo esc_html($title);

}

endif;

function tracian_add_wpb_to_body_if_shortcode($classes) {
    global $post;
    if (isset($post->post_content) && false !== stripos($post->post_content, '[vc_row')) {
        array_push($classes, 'wpb-is-on');
    } else {
        array_push($classes, 'wpb-is-off');
    }
    return $classes;
}
add_filter('body_class', 'tracian_add_wpb_to_body_if_shortcode', 100, 1);


/* Modify the titles */

add_filter( 'get_the_archive_title', function ( $title ) {

    if( is_category() ) {
        $title = single_cat_title( '', false );
    }

    if ( is_post_type_archive() ) {
        $title = post_type_archive_title( '', false );
    }

    return $title;

});