<?php
/**
 * Suppress certain WooCommerce admin notices
 */
function tracian_wc_suppress_nags() {
    if ( class_exists( 'WC_Admin_Notices' ) ) {
        // Remove the "you have outdated template files" nag
        WC_Admin_Notices::remove_notice( 'template_files' );
        
        // Remove the "install pages" and "wc-install" nag
        WC_Admin_Notices::remove_notice( 'install' );
    }
}
add_action( 'wp_loaded', 'tracian_wc_suppress_nags', 99 );

/**
 * Hide shop page title
 */
add_filter('woocommerce_show_page_title', 'tracian_remove_shop_title' );
function tracian_remove_shop_title() {
    return false;
}

/*
 * Add custom pagination
 */
function tracian_wc_pagination() {
    tracian_pagination();       
}
remove_action('woocommerce_after_shop_loop', 'woocommerce_pagination', 10);
add_action( 'woocommerce_after_shop_loop', 'tracian_wc_pagination', 10);

/**
 * My account function
 **/

if ( ! function_exists('tracian_wc_myaccount') ) { 
function tracian_wc_myaccount() {
ob_start();
?>
    <a class="top-header-myaccount" href="<?php echo get_permalink( wc_get_page_id('myaccount') ); ?>" title="<?php esc_attr_e('My account','tracian'); ?>"></a>
    
    <?php return ob_get_clean(); ?>

<?php } 

}

/**
 * Minicart function
 **/
if ( ! function_exists('tracian_wc_minicart') ) { 
function tracian_wc_minicart() {
ob_start();
?>
    <a class="top-header-cart" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_attr_e('View your shopping cart', 'tracian'); ?>">
        <?php
            if (WC()->cart->get_cart_contents_count() > 0) {
                echo '<span class="count">' . WC()->cart->get_cart_contents_count() . '</span>';
            } 
        ?>
    </a>

    <?php return ob_get_clean(); ?>

<?php } 

}

add_filter( 'woocommerce_add_to_cart_fragments', 'tracian_wc_minicart_fragment' );
if ( ! function_exists( 'tracian_wc_minicart_fragment' ) ) {
    function tracian_wc_minicart_fragment( $fragments ) {
        $fragments['.builtin-minicart'] = '<li class="builtin-minicart">' . tracian_wc_minicart() .'</li>';
        return $fragments;
    }
}


if ( ! function_exists( 'tracian_open_product_image_wrap' ) ) {
    /**
     * Product image wrap - open
     */
    function tracian_open_product_image_wrap() {
        echo '<div class="product-image-wrap">';
    }
}

if ( ! function_exists( 'tracian_close_product_image_wrap' ) ) {
    /**
     * Product image wrap - close
     */
    function tracian_close_product_image_wrap() {
        echo '</div>';
    }
}

if ( ! function_exists( 'tracian_open_product_meta_wrap' ) ) {
    /**
     * Product meta wrap - open
     */
    function tracian_open_product_meta_wrap() {
        echo '<div class="product-meta-wrap">';
    }
}

if ( ! function_exists( 'tracian_close_product_meta_wrap' ) ) {
    /**
     * Product meta wrap - close
     */
    function tracian_close_product_meta_wrap() {
        echo '</div>';
    }
}

if ( ! function_exists( 'tracian_open_scrolly_div' ) ) {
    /**
     * Wrap the product image gallery and summary - open div
     */
    function tracian_open_scrolly_div() {
        echo '<div class="scrolly">';
    }
}

if ( ! function_exists( 'tracian_close_scrolly_div' ) ) {
    /**
     * Wrap the product image gallery and summary - close div
     */
    function tracian_close_scrolly_div() {
        echo '</div>';
    }
}

if ( ! function_exists( 'tracian_add_permalink_to_title' ) ) {
    /**
     * Add product permalink to product title
     */
    function tracian_add_permalink_to_title() {
        echo '<h2 class="woocommerce-loop-product__title"><a href="'.get_the_permalink().'">' . get_the_title() . '</a></h2>';
    }
}

if ( ! function_exists( 'tracian_category_on_title' ) ) {
    /**
     * Add product category on top of the product title
     */
    function tracian_category_on_title() {
        global $product;
        echo wc_get_product_category_list( $product->get_id(), ', ', '<span class="product_posted_in">', '</span>' );
    }
}

if ( ! function_exists( 'tracian_product_description' ) ) {
    /**
     * Add product description before upsells
     */
    function tracian_product_description() {
        echo '<div class="clear"></div>';
        wc_get_template( 'single-product/tabs/description.php' );
    }
}

if ( ! function_exists( 'tracian_rename_additional_information_tab' ) ) {
    /**
     * Add product description before upsells
     */
    function tracian_rename_additional_information_tab( $tabs ) {
        $tabs['additional_information']['title']    = esc_html__( 'Product Data', 'tracian' );
        return $tabs;
    }
}

if ( ! function_exists( 'tracian_remove_description_tab' ) ) {
    /**
     * Remove Description tab 
     */
    function tracian_remove_description_tab( $tabs ) {
        unset( $tabs['description'] ); 
        return $tabs;
    }
}

if ( ! function_exists( 'tracian_product_factsheet_link' ) ) {
    /**
     * PDF factsheet link
     */
    function tracian_product_factsheet_link() {
        $factsheet_doc = _get_field('gg_product_fact_sheet');
        if ($factsheet_doc) :
        ?>
        
            <a class="product-factsheet" href="<?php echo esc_url($factsheet_doc); ?> ">
                <svg class="svg-icon-download" viewBox="0 0 20 20">
                    <path fill="#000000" d="M9.634,10.633c0.116,0.113,0.265,0.168,0.414,0.168c0.153,0,0.308-0.06,0.422-0.177l4.015-4.111c0.229-0.235,0.225-0.608-0.009-0.836c-0.232-0.229-0.606-0.222-0.836,0.009l-3.604,3.689L6.35,5.772C6.115,5.543,5.744,5.55,5.514,5.781C5.285,6.015,5.29,6.39,5.522,6.617L9.634,10.633z"></path>
                    <path fill="#000000" d="M17.737,9.815c-0.327,0-0.592,0.265-0.592,0.591v2.903H2.855v-2.903c0-0.327-0.264-0.591-0.591-0.591c-0.327,0-0.591,0.265-0.591,0.591V13.9c0,0.328,0.264,0.592,0.591,0.592h15.473c0.327,0,0.591-0.264,0.591-0.592v-3.494C18.328,10.08,18.064,9.815,17.737,9.815z"></path>
                </svg>
                <span><?php esc_html_e('Download PDF factsheet','tracian');?></span>
            </a>
        
        <?php endif;
    }
}


if ( ! function_exists( 'tracian_product_awards' ) ) {
    /**
     * PDF factsheet link
     */
    function tracian_product_awards() {
        ?>

        <?php 
        if ( class_exists( 'acf' ) ) :
        if ( have_rows('gg_product_awards') ): ?>

            <table class="awards-list">

            <?php while( have_rows('gg_product_awards') ): the_row(); 

                // vars
                $award_points = get_sub_field('gg_award_points');
                $award_name   = get_sub_field('gg_award_name');
                $award_icon   = get_sub_field('gg_award_icon');

                ?>

                <tr>

                    <?php if( $award_points ): ?>
                        <td class="award-points"><?php echo esc_html($award_points); ?></td>
                    <?php endif; ?>
                    <?php if( $award_name ): ?>
                        <td class="award-name"><?php echo esc_html($award_name); ?></td>
                    <?php endif; ?>
                    <?php if( $award_icon ): ?>
                        <td class="award-icon"><img src="<?php echo esc_url($award_icon); ?>" alt="" /></td>
                    <?php endif; ?>

                </tr>

            <?php endwhile; ?>

            </table>

        <?php endif; endif; ?>
        
        <?php
    }
}

if ( ! function_exists( 'tracian_open_my_account_wrapper' ) ) {
    /**
     * Wrap my account page - open div
     */
    function tracian_open_my_account_wrapper() {
        echo '<div class="woocommerce-MyAccount-content-wrapper">';
    }
}

if ( ! function_exists( 'tracian_close_my_account_wrapper' ) ) {
    /**
     * Wrap my account page - close div
     */
    function tracian_close_my_account_wrapper() {
        echo '</div>';
    }
}


/* Store theme options */


/* Shop page */

/**
 * Enable/Disable Sale Flash
 */
if ( _get_field('gg_store_sale_flash','option', true) === false ) {
    remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
}

/**
 * Enable/Disable Products price
 */
if ( _get_field('gg_store_products_price','option', true) === false ) {
    remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10);
}

/**
 * Enable/Disable Add to cart
 */
if ( _get_field('gg_store_add_to_cart','option', true) === false ) {
    remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_add_to_cart',12);
}

/**
 * Options for product page
 */

/**
 * Enable/Disable Product awards
 */
if ( _get_field('gg_product_awards','option', true) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'tracian_product_awards', 6);
}

/**
 * Enable/Disable Product PDF factsheet
 */
if ( _get_field('gg_product_pdf_factsheet','option', true) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'tracian_product_factsheet_link', 75);
}

/*Sale flash*/
if ( _get_field('gg_product_sale_flash','option', true) === false ) {
    remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10);
}

/*Price*/
if ( _get_field('gg_product_products_price','option', true) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 25);
}

/*Product summary*/
if ( _get_field('gg_product_products_excerpt','option', true) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20);
} 

/*Add to cart*/
if ( _get_field('gg_product_add_to_cart','option', true) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30);
}

/*Meta*/
if ( _get_field('gg_product_products_meta','option', false) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 80 );
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 80 );
}

/**
 * Enable/Disable Related products
 */
if ( _get_field('gg_product_related_products','option', true) === false ) {
    remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
}

/**
 * Enable/Disable Up Sells products
 */
if ( _get_field('gg_product_upsells_products','option', true) === false ) {
    remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
}


/**
 * Enable/Disable product data tabs
 */
add_filter( 'woocommerce_product_tabs', 'tracian_remove_product_tabs', 98 );
function tracian_remove_product_tabs( $tabs ) {

    if ( _get_field('gg_product_reviews_tab','option', true) === false ) {
        unset( $tabs['reviews'] );
    }
    if ( _get_field('gg_product_attributes_tab','option', true) === false ) {
        unset( $tabs['additional_information'] );
    }

    return $tabs;
}

/**
 * Enable/Disable produc main description
 */
if ( _get_field('gg_product_description_tab','option', true) === false ) {
    remove_action( 'woocommerce_after_single_product_summary', 'tracian_product_description', 12 );
}

/**
 * Enable/Disable Cross Sells products
 */
if ( _get_field('gg_product_crosssells_products','option', true) === false ) {
    remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
}

/**
 * Catalog mode functions (must be always the last function)
 */
if ( _get_field('gg_store_catalog_mode','option', false ) === true ) {
    // Remove add to cart button from the product loop
    remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_add_to_cart',12);
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );

    // Remove add to cart button from the product details page
    remove_action( 'woocommerce_before_add_to_cart_form', 'woocommerce_template_single_product_add_to_cart', 10, 2);
    
    add_filter( 'woocommerce_add_to_cart_validation', '__return_false', 10, 2 );

    // check for clear-cart get param to clear the cart
    add_action( 'init', 'tracian_wc_clear_cart_url' );
    function tracian_wc_clear_cart_url() {    
        if ( isset( $_GET['clear-cart'] ) ) {
            WC()->cart->empty_cart();
        } 
    }

    add_action( 'wp', 'tracian_check_pages_redirect');
    function tracian_check_pages_redirect() {
        $cart     = is_page( wc_get_page_id( 'cart' ) );
        $checkout = is_page( wc_get_page_id( 'checkout' ) );

        if ( $cart || $checkout ) {
            wp_redirect( esc_url( home_url( '/' ) ) );
            exit;
        }
    }
    
}
