<?php
/**
 * Plugin Name:			OKThemes Tracian Social Share
 * Description:			Social share functionality for Tracian theme
 * Version:				1.0
 * Author:				OKThemes
 * Author URI:			https://okthemes.com/
 *
 * Text Domain: tracian-social-share
 * Domain Path: /languages/
 *
 * @package Tracian_Social_Share
 * @category Core
 * @author OKThemes
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Returns the main instance of Tracian_Social_Share to prevent the need to use globals.
 *
 * @since  1.0.0
 * @return object Tracian_Social_Share
 */
function Tracian_Social_Share() {
	return Tracian_Social_Share::instance();
} // End Tracian_Social_Share()

Tracian_Social_Share();

/**
 * Main Tracian_Social_Share Class
 *
 * @class Tracian_Social_Share
 * @version	1.0.0
 * @since 1.0.0
 * @package	Tracian_Social_Share
 */
final class Tracian_Social_Share {
	/**
	 * Tracian_Social_Share The single instance of Tracian_Social_Share.
	 * @var 	object
	 * @access  private
	 * @since 	1.0.0
	 */
	private static $_instance = null;

	/**
	 * The token.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $token;

	/**
	 * The version number.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $version;

	// Admin - Start
	/**
	 * The admin object.
	 * @var     object
	 * @access  public
	 * @since   1.0.0
	 */
	public $admin;

	/**
	 * Constructor function.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function __construct( $widget_areas = array() ) {
		$this->token 			= 'tracian-social-share';
		$this->plugin_url 		= plugin_dir_url( __FILE__ );
		$this->plugin_path 		= plugin_dir_path( __FILE__ );
		$this->version 			= '1.0';

		register_activation_hook( __FILE__, array( $this, 'install' ) );

		add_action( 'init', array( $this, 'tracian_load_plugin_textdomain' ) );

		add_action( 'init', array( $this, 'tracian_social_share_setup' ) );
	}

	/**
	 * Main Tracian_Social_Share Instance
	 *
	 * Ensures only one instance of Tracian_Social_Share is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @static
	 * @see Tracian_Social_Share()
	 * @return Main Tracian_Social_Share instance
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) )
			self::$_instance = new self();
		return self::$_instance;
	} // End instance()

	/**
	 * Load the localisation file.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function tracian_load_plugin_textdomain() {
		load_plugin_textdomain( 'tracian-social-share', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}

	/**
	 * Cloning is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __clone() {
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?' ), '1.0.0' );
	}

	/**
	 * Unserializing instances of this class is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __wakeup() {
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?' ), '1.0.0' );
	}

	/**
	 * Installation.
	 * Runs on activation. Logs the version number and assigns a notice message to a WordPress option.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function install() {
		$this->_log_version_number();
	}

	/**
	 * Log the plugin version number.
	 * @access  private
	 * @since   1.0.0
	 * @return  void
	 */
	private function _log_version_number() {
		// Log the version number.
		update_option( $this->token . '-version', $this->version );
	}

	/**
	 * Setup all the things.
	 * Only executes if OceanWP or a child theme using OceanWP as a parent is active and the extension specific filter returns true.
	 * @return void
	 */
	public function tracian_social_share_setup() {

		add_action( 'wp_enqueue_scripts', array( $this, 'get_style' ), 999 );
		add_action( 'tracian_social_share', array( $this, 'tracian_social_share' ) );

	}

	
	/**
	 * Enqueue style.
	 * @since   1.0.0
	 */
	public function get_style() {

		// Load main stylesheet
		wp_enqueue_style( 'tracian-social-share-style', plugins_url( '/assets/css/style.css', __FILE__ ) );

	}

	/**
	 * Social sharing links
	 */
	public function tracian_social_share() {

		$file 		= $this->plugin_path . 'template/social-share.php';
		$theme_file = get_stylesheet_directory() . '/parts/part-socialshare.php';

		if ( file_exists( $theme_file ) ) {
			$file = $theme_file;
		}

		if ( file_exists( $file ) ) {
			include $file;
		}

	}

} // End Class